@@ -28,9 +28,7 @@ class FieldAncillary(mixin.PropertiesData,
 
     **NetCDF interface**
 
-    The netCDF variable name of the construct may be accessed with the
-    `nc_set_variable`, `nc_get_variable`, `nc_del_variable` and
-    `nc_has_variable` methods.
+    {{netcdf variable}}
 
     '''
 
