@@ -1,13 +1,22 @@
-from numpy import argsort    as numpy_argsort
+import logging
+
+from numpy import argsort as numpy_argsort
 from numpy import atleast_1d as numpy_atleast_1d
-from numpy import ndarray    as numpy_ndarray
+from numpy import ndarray as numpy_ndarray
 
 from copy import deepcopy
 
-from .functions import RTOL, ATOL, equals
+from .functions import equals as cf_equals
+from .functions import (atol as cf_atol,
+                        rtol as cf_rtol)
 from .functions import inspect as cf_inspect
 
-from .decorators import _deprecated_kwarg_check
+from .decorators import (_deprecated_kwarg_check,
+                         _manage_log_level_via_verbosity,
+                         _display_or_return)
+
+
+logger = logging.getLogger(__name__)
 
 
 class Flags:
@@ -255,6 +264,7 @@ class Flags:
         '''
         return deepcopy(self)
 
+    @_display_or_return
     def dump(self, display=True, _level=0):
         '''Return a string containing a full description of the instance.
 
@@ -282,16 +292,12 @@ class Flags:
                 string.append('%s%s = %s' % (indent1, attr[1:], list(value)))
         # --- End: for
 
-        string = '\n'.join(string)
-
-        if display:
-            print(string)
-        else:
-            return(string)
+        return '\n'.join(string)
 
     @_deprecated_kwarg_check('traceback')
+    @_manage_log_level_via_verbosity
     def equals(self, other, rtol=None, atol=None,
-               ignore_fill_value=False, verbose=False,
+               ignore_fill_value=False, verbose=None,
                traceback=False):
         '''True if two groups of flags are logically equal, False otherwise.
 
@@ -304,11 +310,11 @@ class Flags:
 
         atol: float, optional
             The absolute tolerance for all numerical comparisons, By
-            default the value returned by the `ATOL` function is used.
+            default the value returned by the `atol` function is used.
 
         rtol: float, optional
             The relative tolerance for all numerical comparisons, By
-            default the value returned by the `RTOL` function is used.
+            default the value returned by the `rtol` function is used.
 
         ignore_fill_value: bool, optional
             If True then data arrays with different fill values are
@@ -338,13 +344,12 @@ class Flags:
         '''
         # Check that each instance is the same type
         if self.__class__ != other.__class__:
-            if verbose:
-                print(
-                    "%s: Different type: %s, %s" % (
-                        self.__class__.__name__,
-                        self.__class__.__name__, other.__class__.__name__
-                    )
-                )  # pragma: no cover
+            logger.info(
+                "%s: Different type: %s, %s" % (
+                    self.__class__.__name__,
+                    self.__class__.__name__, other.__class__.__name__
+                )
+            )  # pragma: no cover
             return False
 
         self.sort()
@@ -352,40 +357,41 @@ class Flags:
 
         # Set default tolerances
         if rtol is None:
-            rtol = RTOL()
+            rtol = float(cf_rtol())
+
         if atol is None:
-            atol = ATOL()
+            atol = float(cf_atol())
 
         for attr in ('_flag_meanings', '_flag_values', '_flag_masks'):
             if hasattr(self, attr):
                 if not hasattr(other, attr):
-                    if verbose:
-                        print(
-                            "%s: Different attributes: %s" %
-                            (self.__class__.__name__, attr[1:])
-                        )  # pragma: no cover
+                    logger.info(
+                        "%s: Different attributes: %s" %
+                        (self.__class__.__name__, attr[1:])
+                    )  # pragma: no cover
                     return False
 
                 x = getattr(self, attr)
                 y = getattr(other, attr)
 
-                if (x.shape != y.shape or
-                    not equals(x, y, rtol=rtol, atol=atol,
-                               ignore_fill_value=ignore_fill_value,
-                               verbose=verbose)):
-                    if verbose:
-                        print(
-                            "%s: Different '%s': %r, %r" %
-                            (self.__class__.__name__, attr[1:], x, y)
-                        )  # pragma: no cover
+                if (
+                        x.shape != y.shape
+                        or not cf_equals(x, y,
+                                         rtol=rtol, atol=atol,
+                                         ignore_fill_value=ignore_fill_value,
+                                         verbose=verbose)
+                ):
+                    print(
+                        "%s: Different '%s': %r, %r" %
+                        (self.__class__.__name__, attr[1:], x, y)
+                    )  # pragma: no cover
                     return False
 
             elif hasattr(other, attr):
-                if verbose:
-                    print(
-                        "%s: Different attributes: %s" %
-                        (self.__class__.__name__, attr[1:])
-                    )  # pragma: no cover
+                print(
+                    "%s: Different attributes: %s" %
+                    (self.__class__.__name__, attr[1:])
+                )  # pragma: no cover
                 return False
         # --- End: for
 
@@ -439,5 +445,4 @@ class Flags:
                 array[...] = array[indices]
         # --- End: for
 
-
 # --- End: class
