@@ -1,12 +1,12 @@
+'''.. note:: This class is not in the cf.mixin package because it
+             needs to be imported by cf.Data, and some of the other
+             mixin classes in cf.mixin themsleves import cf.Data,
+             which would lead to a circular import situation.
+
+'''
 from .docstring import _docstring_substitution_definitions
 
 
-# Note: This class is not in the cf.mixin package because it needs to
-#       be imported by cf.Data, and some of the other mixin classes in
-#       cf.mixin themsleves import cf.Data, which would lead to a
-#       circular import situation.
-
-
 class Container:
     '''Mixin class for storing components.
 
@@ -22,7 +22,7 @@ class Container:
 
     See `_docstring_substitutions` for details.
 
-    .. versionaddedd:: 3.7.0
+    .. versionadded:: 3.7.0
 
     .. seealso:: `_docstring_substitutions`
 
