@@ -1,6 +1,5 @@
 import datetime
 import os
-import time
 import unittest
 
 import numpy
@@ -9,23 +8,23 @@ import cf
 
 
 class AuxiliaryCoordinateTest(unittest.TestCase):
-    def setUp(self):
-        self.filename = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)), 'test_file.nc')
-        aux1 = cf.AuxiliaryCoordinate()
-        aux1.standard_name = 'latitude'
-        a = numpy.array(
-            [-30, -23.5, -17.8123, -11.3345, -0.7, -0.2, 0, 0.2, 0.7,
-             11.30003, 17.8678678, 23.5, 30]
-        )
-        aux1.set_data(cf.Data(a, 'degrees_north'))
-        bounds = cf.Bounds()
-        b = numpy.empty(a.shape + (2,))
-        b[:, 0] = a - 0.1
-        b[:, 1] = a + 0.1
-        bounds.set_data(cf.Data(b))
-        aux1.set_bounds(bounds)
-        self.aux1 = aux1
+    filename = os.path.join(
+        os.path.dirname(os.path.abspath(__file__)), 'test_file.nc')
+#    f = cf.read(filename)[0]
+
+    aux1 = cf.AuxiliaryCoordinate()
+    aux1.standard_name = 'latitude'
+    a = numpy.array(
+        [-30, -23.5, -17.8123, -11.3345, -0.7, -0.2, 0, 0.2, 0.7,
+         11.30003, 17.8678678, 23.5, 30]
+    )
+    aux1.set_data(cf.Data(a, 'degrees_north'))
+    bounds = cf.Bounds()
+    b = numpy.empty(a.shape + (2,))
+    b[:, 0] = a - 0.1
+    b[:, 1] = a + 0.1
+    bounds.set_data(cf.Data(b))
+    aux1.set_bounds(bounds)
 
     def test_AuxiliaryCoordinate_mask_invalid(self):
         a = self.aux1.copy()
@@ -50,8 +49,6 @@ class AuxiliaryCoordinateTest(unittest.TestCase):
         _ = str(x)
         _ = x.dump(display=False)
 
-        self.assertTrue(x.isauxiliary)
-
     def test_AuxiliaryCoordinate_bounds(self):
         f = cf.read(self.filename)[0]
         d = f.dimension_coordinates('X').value()
@@ -65,42 +62,33 @@ class AuxiliaryCoordinateTest(unittest.TestCase):
         x = f.auxiliary_coordinates('latitude').value()
 
         x.positive = 'up'
-        self.assertTrue(x.positive == 'up')
+        self.assertEqual(x.positive, 'up')
         del x.positive
         self.assertIsNone(getattr(x, 'positive', None))
 
         x.axis = 'Z'
-        self.assertTrue(x.axis == 'Z')
+        self.assertEqual(x.axis, 'Z')
         del x.axis
         self.assertIsNone(getattr(x, 'axis', None))
 
-
-#        x.axis = 'T'
-#        self.assertTrue(x.ndim == 2)
-#        self.assertTrue(x.T)
-#        self.assertTrue(x.ctype == 'T')
-
         d = f.dimension_coordinates('X').value()
         x = cf.AuxiliaryCoordinate(source=d)
-#       x.axis = 'T'
-#       self.assertTrue(x.ndim == 1)
-#       self.assertTrue(x.T)
 
     def test_AuxiliaryCoordinate_insert_dimension(self):
         f = cf.read(self.filename)[0]
         d = f.dimension_coordinates('X').value()
         x = cf.AuxiliaryCoordinate(source=d)
 
-        self.assertTrue(x.shape == (9,))
-        self.assertTrue(x.bounds.shape == (9, 2))
+        self.assertEqual(x.shape, (9,))
+        self.assertEqual(x.bounds.shape, (9, 2))
 
         y = x.insert_dimension(0)
-        self.assertTrue(y.shape == (1, 9))
-        self.assertTrue(y.bounds.shape == (1, 9, 2), y.bounds.shape)
+        self.assertEqual(y.shape, (1, 9))
+        self.assertEqual(y.bounds.shape, (1, 9, 2), y.bounds.shape)
 
         x.insert_dimension(-1, inplace=True)
-        self.assertTrue(x.shape == (9, 1))
-        self.assertTrue(x.bounds.shape == (9, 1, 2), x.bounds.shape)
+        self.assertEqual(x.shape, (9, 1))
+        self.assertEqual(x.bounds.shape, (9, 1, 2), x.bounds.shape)
 
     def test_AuxiliaryCoordinate_transpose(self):
         f = cf.read(self.filename)[0]
@@ -110,16 +98,16 @@ class AuxiliaryCoordinateTest(unittest.TestCase):
             data=cf.Data(numpy.arange(9*10*4).reshape(9, 10, 4)))
         x.set_bounds(bounds)
 
-        self.assertTrue(x.shape == (9, 10))
-        self.assertTrue(x.bounds.shape == (9, 10, 4))
+        self.assertEqual(x.shape, (9, 10))
+        self.assertEqual(x.bounds.shape, (9, 10, 4))
 
         y = x.transpose()
-        self.assertTrue(y.shape == (10, 9))
-        self.assertTrue(y.bounds.shape == (10, 9, 4), y.bounds.shape)
+        self.assertEqual(y.shape, (10, 9))
+        self.assertEqual(y.bounds.shape, (10, 9, 4), y.bounds.shape)
 
         x.transpose([1, 0], inplace=True)
-        self.assertTrue(x.shape == (10, 9))
-        self.assertTrue(x.bounds.shape == (10, 9, 4), x.bounds.shape)
+        self.assertEqual(x.shape, (10, 9))
+        self.assertEqual(x.bounds.shape, (10, 9, 4), x.bounds.shape)
 
     def test_AuxiliaryCoordinate_squeeze(self):
         f = cf.read(self.filename)[0]
@@ -131,16 +119,16 @@ class AuxiliaryCoordinateTest(unittest.TestCase):
         x.insert_dimension(1, inplace=True)
         x.insert_dimension(0, inplace=True)
 
-        self.assertTrue(x.shape == (1, 9, 1, 10))
-        self.assertTrue(x.bounds.shape == (1, 9, 1, 10, 4))
+        self.assertEqual(x.shape, (1, 9, 1, 10))
+        self.assertEqual(x.bounds.shape, (1, 9, 1, 10, 4))
 
         y = x.squeeze()
-        self.assertTrue(y.shape == (9, 10))
-        self.assertTrue(y.bounds.shape == (9, 10, 4), y.bounds.shape)
+        self.assertEqual(y.shape, (9, 10))
+        self.assertEqual(y.bounds.shape, (9, 10, 4), y.bounds.shape)
 
         x.squeeze(2, inplace=True)
-        self.assertTrue(x.shape == (1, 9, 10))
-        self.assertTrue(x.bounds.shape == (1, 9, 10, 4), x.bounds.shape)
+        self.assertEqual(x.shape, (1, 9, 10))
+        self.assertEqual(x.bounds.shape, (1, 9, 10, 4), x.bounds.shape)
 
     def test_AuxiliaryCoordinate_floor(self):
         aux = self.aux1.copy()
@@ -259,9 +247,9 @@ class AuxiliaryCoordinateTest(unittest.TestCase):
     def test_AuxiliaryCoordinate_cyclic(self):
         aux = self.aux1.copy()
 
-        self.assertTrue(aux.cyclic() == set())
-        self.assertTrue(aux.cyclic(0) == set())
-        self.assertTrue(aux.cyclic() == set([0]))
+        self.assertEqual(aux.cyclic(), set())
+        self.assertEqual(aux.cyclic(0), set())
+        self.assertEqual(aux.cyclic(), set([0]))
 
     def test_AuxiliaryCoordinate_roll(self):
         aux = self.aux1.copy()
@@ -327,9 +315,9 @@ class AuxiliaryCoordinateTest(unittest.TestCase):
 
         self.assertIsNone(aux.clip(-15, 25, inplace=True))
 
-
 # --- End: class
 
+
 if __name__ == "__main__":
     print('Run date:', datetime.datetime.now())
     cf.environment()
