@@ -1,11 +1,9 @@
-from __future__ import print_function
 import datetime
 import inspect
 import os
 import tempfile
 import unittest
 
-from distutils.version import LooseVersion
 
 import numpy
 import netCDF4
@@ -54,10 +52,10 @@ class DSGTest(unittest.TestCase):
 
         f = cf.read(self.geometry_1_file, verbose=0)
 
-        self.assertTrue(len(f) == 2, 'f = '+repr(f))
+        self.assertEqual(len(f), 2, 'f = '+repr(f))
         for g in f:
             self.assertTrue(g.equals(g.copy(), verbose=2))
-            self.assertTrue(len(g.auxiliary_coordinates) == 2)
+            self.assertEqual(len(g.auxiliary_coordinates), 2)
 
         g = f[0]
         for axis in ('X', 'Y'):
@@ -69,7 +67,7 @@ class DSGTest(unittest.TestCase):
         cf.write(f, self.tempfilename, Conventions='CF-'+VN, verbose=0)
 
         f2 = cf.read(self.tempfilename, verbose=0)
-        self.assertTrue(len(f2) == 2, 'f2 = '+repr(f2))
+        self.assertEqual(len(f2), 2, 'f2 = '+repr(f2))
         for a, b in zip(f, f2):
             self.assertTrue(a.equals(b, verbose=2))
 
@@ -101,11 +99,11 @@ class DSGTest(unittest.TestCase):
 
         f = cf.read(self.geometry_2_file, verbose=0)
 
-        self.assertTrue(len(f) == 2, 'f = '+repr(f))
+        self.assertEqual(len(f), 2, 'f = '+repr(f))
 
         for g in f:
             self.assertTrue(g.equals(g.copy(), verbose=2))
-            self.assertTrue(len(g.auxiliary_coordinates) == 3)
+            self.assertEqual(len(g.auxiliary_coordinates), 3)
 
         g = f[0]
         for axis in ('X', 'Y', 'Z'):
@@ -118,7 +116,7 @@ class DSGTest(unittest.TestCase):
 
         f2 = cf.read(self.tempfilename, verbose=0)
 
-        self.assertTrue(len(f2) == 2, 'f2 = '+repr(f2))
+        self.assertEqual(len(f2), 2, 'f2 = '+repr(f2))
 
         for a, b in zip(f, f2):
             self.assertTrue(a.equals(b, verbose=2))
@@ -138,11 +136,11 @@ class DSGTest(unittest.TestCase):
 
         f = cf.read(self.geometry_3_file, verbose=0)
 
-        self.assertTrue(len(f) == 2, 'f = '+repr(f))
+        self.assertEqual(len(f), 2, 'f = '+repr(f))
 
         for g in f:
             self.assertTrue(g.equals(g.copy(), verbose=2))
-            self.assertTrue(len(g.auxiliary_coordinates) == 3)
+            self.assertEqual(len(g.auxiliary_coordinates), 3)
 
         g = f[0]
         for axis in ('X', 'Y', 'Z'):
@@ -155,7 +153,7 @@ class DSGTest(unittest.TestCase):
 
         f2 = cf.read(self.tempfilename, verbose=0)
 
-        self.assertTrue(len(f2) == 2, 'f2 = '+repr(f2))
+        self.assertEqual(len(f2), 2, 'f2 = '+repr(f2))
 
         for a, b in zip(f, f2):
             self.assertTrue(a.equals(b, verbose=2))
@@ -166,11 +164,11 @@ class DSGTest(unittest.TestCase):
 
         f = cf.read(self.geometry_4_file, verbose=0)
 
-        self.assertTrue(len(f) == 2, 'f = '+repr(f))
+        self.assertEqual(len(f), 2, 'f = '+repr(f))
 
         for g in f:
             self.assertTrue(g.equals(g.copy(), verbose=2))
-            self.assertTrue(len(g.auxiliary_coordinates) == 3)
+            self.assertEqual(len(g.auxiliary_coordinates), 3)
 
         for axis in ('X', 'Y'):
             coord = g.construct('axis='+axis)
@@ -182,7 +180,7 @@ class DSGTest(unittest.TestCase):
 
         f2 = cf.read(self.tempfilename, verbose=0)
 
-        self.assertTrue(len(f2) == 2, 'f2 = '+repr(f2))
+        self.assertEqual(len(f2), 2, 'f2 = '+repr(f2))
 
         for a, b in zip(f, f2):
             self.assertTrue(a.equals(b, verbose=2))
@@ -204,11 +202,11 @@ class DSGTest(unittest.TestCase):
                               self.geometry_interior_ring_file_2):
             f = cf.read(geometry_file, verbose=0)
 
-            self.assertTrue(len(f) == 2, 'f = '+repr(f))
+            self.assertEqual(len(f), 2, 'f = '+repr(f))
 
             for g in f:
                 self.assertTrue(g.equals(g.copy(), verbose=2))
-                self.assertTrue(len(g.auxiliary_coordinates) == 4)
+                self.assertEqual(len(g.auxiliary_coordinates), 4)
 
             g = f[0]
             for axis in ('X', 'Y'):
@@ -221,7 +219,7 @@ class DSGTest(unittest.TestCase):
 
             f2 = cf.read(self.tempfilename, verbose=0)
 
-            self.assertTrue(len(f2) == 2, 'f2 = '+repr(f2))
+            self.assertEqual(len(f2), 2, 'f2 = '+repr(f2))
 
             for a, b in zip(f, f2):
                 self.assertTrue(a.equals(b, verbose=2))
@@ -231,30 +229,26 @@ class DSGTest(unittest.TestCase):
 
             self.assertTrue(c.interior_ring.equals(
                 g.construct('longitude').get_interior_ring()))
-            self.assertTrue(c.interior_ring.data.ndim == c.data.ndim + 1)
-            self.assertTrue(c.interior_ring.data.shape[0] == c.data.shape[0])
+            self.assertEqual(c.interior_ring.data.ndim, c.data.ndim + 1)
+            self.assertEqual(c.interior_ring.data.shape[0], c.data.shape[0])
 
             _ = g.dump(display=False)
 
             d = c.insert_dimension(0)
-            self.assertTrue(d.data.shape == (1,) + c.data.shape)
-            self.assertTrue(
-                d.interior_ring.data.shape ==
-                (1,) + c.interior_ring.data.shape
-            )
+            self.assertEqual(d.data.shape, (1,) + c.data.shape)
+            self.assertEqual(d.interior_ring.data.shape,
+                             (1,) + c.interior_ring.data.shape)
 
             e = d.squeeze(0)
-            self.assertTrue(e.data.shape == c.data.shape)
-            self.assertTrue(
-                e.interior_ring.data.shape == c.interior_ring.data.shape)
+            self.assertEqual(e.data.shape, c.data.shape)
+            self.assertEqual(e.interior_ring.data.shape,
+                             c.interior_ring.data.shape)
 
             t = d.transpose()
-            self.assertTrue(
-                t.data.shape == d.data.shape[::-1],
-                (t.data.shape, c.data.shape[::-1])
-            )
-            self.assertTrue(
-                t.interior_ring.data.shape ==
+            self.assertEqual(t.data.shape, d.data.shape[::-1],
+                             (t.data.shape, c.data.shape[::-1]))
+            self.assertEqual(
+                t.interior_ring.data.shape,
                 d.interior_ring.data.shape[-2::-1] +
                 (d.interior_ring.data.shape[-1],)
             )
@@ -263,10 +257,11 @@ class DSGTest(unittest.TestCase):
             g = g[1, ...]
             c = g.construct('longitude')
 
-            self.assertTrue(
-                c.interior_ring.data.shape[0] == 1, c.interior_ring.data.shape)
-            self.assertTrue(c.interior_ring.data.ndim == c.data.ndim + 1)
-            self.assertTrue(c.interior_ring.data.shape[0] == c.data.shape[0])
+            self.assertEqual(
+                c.interior_ring.data.shape[0], 1,
+                c.interior_ring.data.shape)
+            self.assertEqual(c.interior_ring.data.ndim, c.data.ndim + 1)
+            self.assertEqual(c.interior_ring.data.shape[0], c.data.shape[0])
 
             # Setting of node count properties
             coord = f[0].construct('axis=Y')
@@ -348,7 +343,7 @@ class DSGTest(unittest.TestCase):
 
 
 if __name__ == '__main__':
-    print('Run date:', datetime.datetime.utcnow())
+    print('Run date:', datetime.datetime.now())
     cf.environment()
     print()
     unittest.main(verbosity=2)
